Generators — linkml documentation

# Generators

A LinkML generator is code that transforms a linkml schema into a datamodel expressed using another framework, or into some other artefact, such as documentation

Contents:

- JSON Schema
  - Example Output
  - Overview
  - Docs
- Markdown
  - Overview
  - Docs
- Python
  - Example Output
  - Overview
  - Docs
  - Additional Notes
  - Code generation for LinkML slots
- Java
  - Overview
  - Docs
  - Additional Notes
  - Biolink Example
  - Alternate Template Example
- SQL DDL
  - Overview
  - Docs
- JSON-LD Contexts
  - Overview
  - Docs
- SPARQL
  - Overview
  - Docs
- ShEx
  - Overview
  - Docs
- Shacl
  - Overview
  - Docs
- TerminusDB
  - Overview
  - Docs
- Owl
  - Overview
  - Docs
- Excel Spreadsheet
  - Example Output
  - Overview
  - Docs
- Project Generator
  - Overview
  - Docs